/* $Id: ssh_paths.h,v 1.5 2000/10/21 23:09:59 andrew Exp $ */

/*
 * Copyright 1999 RedBack Networks, Incorporated.
 * All rights reserved.
 *
 * This software is not in the public domain.  It is distributed 
 * under the terms of the license in the file LICENSE in the
 * same directory as this file.  If you have received a copy of this
 * software without the LICENSE file (which means that whoever gave
 * you this software violated its license) you may obtain a copy from
 * http://www.panix.com/~tls/LICENSE.txt
 */


#ifndef _SSH_PATHS_H
#define _SSH_PATHS_H

#define PATH_LOGIN	"/usr/bin/login"
#define PATH_HOSTKEY	"/etc/ssh_host_key"

/* PATH_AUTHKEYS is realtive to user's home dir. */
#define PATH_AUTHKEYS	_PATH_SSH_USER_DIR "/authorized_keys"

#endif /* _SSH_PATHS_H */
